// \file PostfixIntegrate.hpp
//
// Copyright (C) 2011 ARM Research Labs, LLC.
// See www.armresearch.com for the copyright terms.
//
// This file defines the PostfixIntegrate interface.
//
// $Id$
//
///////////////////////////////////////////////////////////////////////////////////////////////////

#ifndef PostfixIntegratehpp_included
#define PostfixIntegratehpp_included

#include "MtaIntegrate.hpp"

/// Class to manage the SNFMilter integration with postfix.
//
// This class implements the MtaIntegrate interface for postfix.
//
//////////////////////////////////////////////////////////////////////////////////////////////////////////
class PostfixIntegrate : public MtaIntegrate {

public:

    virtual void SetOperatingSystem(std::string OperatingSystemType);

    virtual void Integrate(FileBackup *SaveFile);

    virtual void Unintegrate(FileBackup *SaveFile);

    virtual bool MtaIsRunningDetected();

    virtual bool ReloadMta();

private:

    virtual bool IsIntegrated();

    /// Postfix main.cf file path.
    std::string PostfixMainCfPath;

    /// Postfix master.cf file path.
    std::string PostfixMasterCfPath;

    /// Command to determine whether postfix is running.
    std::string MtaIsRunningCommand;

    /// Command to reload postfix.
    std::string ReloadMtaCommand;

};

#endif
